@@ -15,7 +15,10 @@ pub struct RegexPattern {
 }
 
 impl fmt::Display for RegexPattern {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+    fn fmt(
+        &self,
+        f: &mut fmt::Formatter<'_>,
+    ) -> fmt::Result {
         if self.flags.is_empty() {
             write!(f, "/{}", self.rex)
         } else {
@@ -25,14 +28,20 @@ impl fmt::Display for RegexPattern {
 }
 
 impl RegexPattern {
-    pub fn from(pat: &str, flags: &str) -> Result<Self, PatternError> {
+    pub fn from(
+        pat: &str,
+        flags: &str,
+    ) -> Result<Self, PatternError> {
         Ok(RegexPattern {
             rex: super::build_regex(pat, flags)?,
             flags: flags.to_string(),
         })
     }
     /// return a match if the pattern can be found in the candidate string
-    pub fn find(&self, candidate: &str) -> Option<NameMatch> {
+    pub fn find(
+        &self,
+        candidate: &str,
+    ) -> Option<NameMatch> {
         // note that there's no significative cost related to using
         //  find over is_match
         self.rex.find(candidate).map(|rm| {
@@ -48,5 +57,4 @@ impl RegexPattern {
     pub fn is_empty(&self) -> bool {
         self.rex.as_str().is_empty()
     }
-
 }
