@@ -1,16 +1,11 @@
 use {
-    super::{
-        Internal,
-        Verb,
-        VerbId,
-    },
+    super::{Internal, Verb, VerbId},
     crate::{
         app::*,
         command::Sequence,
         conf::{Conf, VerbConf},
         errors::ConfError,
-        keys::KEY_FORMAT,
-        keys,
+        keys::{self, KEY_FORMAT},
         verb::*,
     },
     crokey::*,
@@ -39,7 +34,10 @@ pub enum PrefixSearchResult<'v, T> {
 
 impl VerbStore {
     pub fn new(conf: &mut Conf) -> Result<Self, ConfError> {
-        let mut store = Self { verbs: Vec::new(), unbound_keys: Vec::new() };
+        let mut store = Self {
+            verbs: Vec::new(),
+            unbound_keys: Vec::new(),
+        };
         for vc in &conf.verbs {
             if let Err(e) = store.add_from_conf(vc) {
                 eprintln!("Invalid verb configuration: {}", e);
@@ -60,9 +58,7 @@ impl VerbStore {
         Ok(store)
     }
 
-    fn add_builtin_verbs(
-        &mut self,
-    ) -> Result<(), ConfError> {
+    fn add_builtin_verbs(&mut self) -> Result<(), ConfError> {
         use super::{ExternalExecutionMode::*, Internal::*};
         self.add_internal(escape).with_key(key!(esc));
 
@@ -73,18 +69,26 @@ impl VerbStore {
         self.add_internal(input_del_char_below).no_doc();
         self.add_internal(input_del_word_left).no_doc();
         self.add_internal(input_del_word_right).no_doc();
-        self.add_internal(input_go_to_end).with_key(key!(end)).no_doc();
+        self.add_internal(input_go_to_end)
+            .with_key(key!(end))
+            .no_doc();
         self.add_internal(input_go_left).no_doc();
         self.add_internal(input_go_right).no_doc();
-        self.add_internal(input_go_to_start).with_key(key!(home)).no_doc();
+        self.add_internal(input_go_to_start)
+            .with_key(key!(home))
+            .no_doc();
         self.add_internal(input_go_word_left).no_doc();
         self.add_internal(input_go_word_right).no_doc();
 
         // arrow keys bindings
         self.add_internal(back);
         self.add_internal(open_stay);
-        self.add_internal(line_down).with_key(key!(down)).with_key(key!('j'));
-        self.add_internal(line_up).with_key(key!(up)).with_key(key!('k'));
+        self.add_internal(line_down)
+            .with_key(key!(down))
+            .with_key(key!('j'));
+        self.add_internal(line_up)
+            .with_key(key!(up))
+            .with_key(key!('k'));
 
         // changing display
         self.add_internal(set_syntax_theme);
@@ -96,11 +100,11 @@ impl VerbStore {
         // for directories and the other one for the other files
         self.add_internal(open_leave) // calls the system open
             .with_condition(FileTypeCondition::File)
-            .with_key(key!(alt-enter))
+            .with_key(key!(alt - enter))
             .with_shortcut("ol");
         self.add_external("cd", "cd {directory}", FromParentShell)
             .with_condition(FileTypeCondition::Directory)
-            .with_key(key!(alt-enter))
+            .with_key(key!(alt - enter))
             .with_shortcut("ol")
             .with_description("change directory and quit");
 
@@ -113,34 +117,29 @@ impl VerbStore {
         self.add_internal(open_preview);
         self.add_internal(close_preview);
         self.add_internal(toggle_preview);
-        self.add_internal(preview_image)
-            .with_shortcut("img");
-        self.add_internal(preview_text)
-            .with_shortcut("txt");
-        self.add_internal(preview_binary)
-            .with_shortcut("hex");
-        self.add_internal(preview_tty)
-            .with_shortcut("tty");
+        self.add_internal(preview_image).with_shortcut("img");
+        self.add_internal(preview_text).with_shortcut("txt");
+        self.add_internal(preview_binary).with_shortcut("hex");
+        self.add_internal(preview_tty).with_shortcut("tty");
         self.add_internal(close_panel_ok);
         self.add_internal(close_panel_cancel)
-            .with_key(key!(ctrl-w));
+            .with_key(key!(ctrl - w));
         #[cfg(unix)]
         self.add_external(
             "copy {newpath}",
             "cp -r {file} {newpath:path-from-parent}",
             StayInBroot,
         )
-            .with_shortcut("cp");
+        .with_shortcut("cp");
         #[cfg(windows)]
         self.add_external(
             "copy {newpath}",
             "xcopy /Q /H /Y /I {file} {newpath:path-from-parent}",
             StayInBroot,
         )
-            .with_shortcut("cp");
+        .with_shortcut("cp");
         #[cfg(feature = "clipboard")]
-        self.add_internal(copy_line)
-            .with_key(key!(alt-c));
+        self.add_internal(copy_line).with_key(key!(alt - c));
         #[cfg(feature = "clipboard")]
         self.add_internal(copy_path);
         #[cfg(unix)]
@@ -149,104 +148,96 @@ impl VerbStore {
             "cp -r {file} {other-panel-directory}",
             StayInBroot,
         )
-            .with_shortcut("cpp");
+        .with_shortcut("cpp");
         #[cfg(windows)]
         self.add_external(
             "copy_to_panel",
             "xcopy /Q /H /Y /I {file} {other-panel-directory}",
             StayInBroot,
         )
-            .with_shortcut("cpp");
-        #[cfg(feature = "trash")]
+        .with_shortcut("cpp");
         self.add_internal(trash);
-        #[cfg(feature = "trash")]
-        self.add_internal(open_trash)
-            .with_shortcut("ot");
-        #[cfg(feature = "trash")]
-        self.add_internal(restore_trashed_file)
-            .with_shortcut("rt");
-        #[cfg(feature = "trash")]
-        self.add_internal(delete_trashed_file)
-            .with_shortcut("dt");
-        #[cfg(feature = "trash")]
-        self.add_internal(purge_trash)
-            .with_shortcut("et");
+        #[cfg(trash)]
+        {
+            self.add_internal(open_trash).with_shortcut("ot");
+            self.add_internal(restore_trashed_file).with_shortcut("rt");
+            self.add_internal(delete_trashed_file).with_shortcut("dt");
+            self.add_internal(purge_trash).with_shortcut("et");
+        }
         #[cfg(unix)]
-        self.add_internal(filesystems)
-            .with_shortcut("fs");
+        self.add_internal(filesystems).with_shortcut("fs");
         self.add_internal(focus_staging_area_no_open);
         // :focus is also hardcoded on Enter on directories
         // but ctrl-f is useful for focusing on a file's parent
         // (and keep the filter)
         self.add_internal(focus)
-            .with_key(key!(L))  // hum... why this one ?
-            .with_key(key!(ctrl-f));
+            .with_key(key!(L)) // hum... why this one ?
+            .with_key(key!(ctrl - f));
         self.add_internal(help)
             .with_key(key!(F1))
             .with_shortcut("?");
-        #[cfg(feature="clipboard")]
-        self.add_internal(input_paste)
-            .with_key(key!(ctrl-v));
+        #[cfg(feature = "clipboard")]
+        self.add_internal(input_paste).with_key(key!(ctrl - v));
         #[cfg(unix)]
         self.add_external(
             "mkdir {subpath}",
             "mkdir -p {subpath:path-from-directory}",
             StayInBroot,
         )
-            .with_shortcut("md");
+        .with_shortcut("md");
         #[cfg(windows)]
         self.add_external(
             "mkdir {subpath}",
             "cmd /c mkdir {subpath:path-from-directory}",
             StayInBroot,
         )
-            .with_shortcut("md");
+        .with_shortcut("md");
         #[cfg(unix)]
         self.add_external(
             "move {newpath}",
             "mv {file} {newpath:path-from-parent}",
             StayInBroot,
         )
-            .with_shortcut("mv");
+        .with_shortcut("mv");
         #[cfg(windows)]
         self.add_external(
             "move {newpath}",
             "cmd /c move /Y {file} {newpath:path-from-parent}",
             StayInBroot,
         )
-            .with_shortcut("mv");
+        .with_shortcut("mv");
         #[cfg(unix)]
         self.add_external(
             "move_to_panel",
             "mv {file} {other-panel-directory}",
             StayInBroot,
         )
-            .with_shortcut("mvp");
+        .with_shortcut("mvp");
         #[cfg(windows)]
         self.add_external(
             "move_to_panel",
             "cmd /c move /Y {file} {other-panel-directory}",
             StayInBroot,
         )
-            .with_shortcut("mvp");
+        .with_shortcut("mvp");
         #[cfg(unix)]
         self.add_external(
             "rename {new_filename:file-name}",
             "mv {file} {parent}/{new_filename}",
             StayInBroot,
         )
-            .with_auto_exec(false)
-            .with_key(key!(f2));
+        .with_auto_exec(false)
+        .with_key(key!(f2));
         #[cfg(windows)]
         self.add_external(
             "rename {new_filename:file-name}",
             "cmd /c move /Y {file} {parent}/{new_filename}",
             StayInBroot,
         )
-            .with_auto_exec(false)
-            .with_key(key!(f2));
+        .with_auto_exec(false)
+        .with_key(key!(f2));
         self.add_internal_bang(start_end_panel)
-            .with_key(key!(ctrl-p));
+            .with_key(key!(ctrl - p));
         // the char keys for mode_input are handled differently as they're not
         // consumed by the command
         self.add_internal(mode_input)
@@ -254,60 +245,53 @@ impl VerbStore {
             .with_key(key!(':'))
             .with_key(key!('/'));
         self.add_internal(previous_match)
-            .with_key(key!(shift-backtab))
+            .with_key(key!(shift - backtab))
             .with_key(key!(backtab));
-        self.add_internal(next_match)
-            .with_key(key!(tab));
-        self.add_internal(no_sort)
-            .with_shortcut("ns");
+        self.add_internal(next_match).with_key(key!(tab));
+        self.add_internal(no_sort).with_shortcut("ns");
         self.add_internal(open_stay)
             .with_key(key!(enter))
             .with_shortcut("os");
-        self.add_internal(open_stay_filter)
-            .with_shortcut("osf");
+        self.add_internal(open_stay_filter).with_shortcut("osf");
         self.add_internal(parent)
             .with_key(key!(h))
             .with_shortcut("p");
         self.add_internal(page_down)
-            .with_key(key!(ctrl-d))
+            .with_key(key!(ctrl - d))
             .with_key(key!(pagedown));
         self.add_internal(page_up)
-            .with_key(key!(ctrl-u))
+            .with_key(key!(ctrl - u))
             .with_key(key!(pageup));
         self.add_internal(panel_left_no_open)
-            .with_key(key!(ctrl-left));
-        self.add_internal(panel_right)
-            .with_key(key!(ctrl-right));
+            .with_key(key!(ctrl - left));
+        self.add_internal(panel_right).with_key(key!(ctrl - right));
         self.add_internal(print_path).with_shortcut("pp");
         self.add_internal(print_relative_path).with_shortcut("prp");
         self.add_internal(print_tree).with_shortcut("pt");
         self.add_internal(quit)
-            .with_key(key!(ctrl-c))
-            .with_key(key!(ctrl-q))
+            .with_key(key!(ctrl - c))
+            .with_key(key!(ctrl - q))
             .with_shortcut("q");
         self.add_internal(refresh).with_key(key!(f5));
-        self.add_internal(root_up)
-            .with_key(key!(ctrl-up));
-        self.add_internal(root_down)
-            .with_key(key!(ctrl-down));
+        self.add_internal(root_up).with_key(key!(ctrl - up));
+        self.add_internal(root_down).with_key(key!(ctrl - down));
         self.add_internal(select_first);
         self.add_internal(select_last);
         self.add_internal(select);
         self.add_internal(show);
         self.add_internal(clear_stage).with_shortcut("cls");
-        self.add_internal(stage)
-            .with_key(key!('+'));
-        self.add_internal(unstage)
-            .with_key(key!('-'));
+        self.add_internal(stage).with_key(key!('+'));
+        self.add_internal(unstage).with_key(key!('-'));
         self.add_internal(stage_all_directories);
-        self.add_internal(stage_all_files)
-            .with_key(key!(ctrl-a));
-        self.add_internal(toggle_stage)
-            .with_key(key!(ctrl-g));
+        self.add_internal(stage_all_files).with_key(key!(ctrl - a));
+        self.add_internal(toggle_stage).with_key(key!(ctrl - g));
         self.add_internal(open_staging_area).with_shortcut("osa");
         self.add_internal(close_staging_area).with_shortcut("csa");
         self.add_internal(toggle_staging_area).with_shortcut("tsa");
         self.add_internal(toggle_tree).with_shortcut("tree");
+        self.add_internal(toggle_watch)
+            .with_shortcut("watch")
+            .with_key(key!(alt - w));
         self.add_internal(sort_by_count).with_shortcut("sc");
         self.add_internal(sort_by_date).with_shortcut("sd");
         self.add_internal(sort_by_size).with_shortcut("ss");
@@ -325,7 +309,7 @@ impl VerbStore {
         self.add_internal(toggle_device_id).with_shortcut("dev");
         self.add_internal(toggle_files).with_shortcut("files");
         self.add_internal(toggle_ignore)
-            .with_key(key!(alt-i))
+            .with_key(key!(alt - i))
             .with_shortcut("gi");
         self.add_internal(toggle_git_file_info).with_shortcut("gf");
         self.add_internal(toggle_git_status).with_shortcut("gs");
@@ -333,18 +317,20 @@ impl VerbStore {
         self.add_internal(set_max_depth);
         self.add_internal(unset_max_depth);
         self.add_internal(toggle_hidden)
-            .with_key(key!(alt-h))
+            .with_key(key!(alt - h))
             .with_shortcut("h");
         #[cfg(unix)]
         self.add_internal(toggle_perm).with_shortcut("perm");
         self.add_internal(toggle_sizes).with_shortcut("sizes");
         self.add_internal(toggle_trim_root);
         self.add_internal(total_search);
-        self.add_internal(search_again).with_key(key!(ctrl-s));
+        self.add_internal(search_again).with_key(key!(ctrl - s));
         self.add_internal(up_tree).with_shortcut("up");
 
-        self.add_internal_with_args(move_panel_divider, "0 1").with_key(key!(alt-'>'));
-        self.add_internal_with_args(move_panel_divider, "0 -1").with_key(key!(alt-'<'));
+        self.add_internal_with_args(move_panel_divider, "0 1")
+            .with_key(key!(alt - '>'));
+        self.add_internal_with_args(move_panel_divider, "0 -1")
+            .with_key(key!(alt - '<'));
 
         self.add_internal(clear_output);
         self.add_internal(write_output);
@@ -357,11 +343,11 @@ impl VerbStore {
         bang: bool,
     ) -> &mut Verb {
         let invocation = internal.invocation_pattern();
-        let execution = VerbExecution::Internal(
-            InternalExecution::from_internal_bang(internal, bang)
-        );
+        let execution =
+            VerbExecution::Internal(InternalExecution::from_internal_bang(internal, bang));
         let description = VerbDescription::from_text(internal.description().to_string());
-        self.add_verb(Some(invocation), execution, description).unwrap()
+        self.add_verb(Some(invocation), execution, description)
+            .unwrap()
     }
 
     fn add_internal(
@@ -376,20 +362,18 @@ impl VerbStore {
         internal: Internal,
         args: &str,
     ) -> &mut Verb {
-        let command =
-            format!("{} {}", internal.name(), args);
-        let execution = VerbExecution::Internal(
-            InternalExecution {
-                internal,
-                bang: false,
-                arg: Some(args.to_string()),
-            }
-        );
+        let command = format!("{} {}", internal.name(), args);
+        let execution = VerbExecution::Internal(InternalExecution {
+            internal,
+            bang: false,
+            arg: Some(args.to_string()),
+        });
         let description = VerbDescription::from_text(command.clone());
-        self.add_verb(Some(&command), execution, description).unwrap()
+        self.add_verb(Some(&command), execution, description)
+            .unwrap()
     }
 
-     fn add_internal_bang(
+    fn add_internal_bang(
         &mut self,
         internal: Internal,
     ) -> &mut Verb {
@@ -402,14 +386,16 @@ impl VerbStore {
         execution_str: &str,
         exec_mode: ExternalExecutionMode,
     ) -> &mut Verb {
-        let execution = VerbExecution::External(
-            ExternalExecution::new(ExecPattern::from_string(execution_str), exec_mode)
-        );
+        let execution = VerbExecution::External(ExternalExecution::new(
+            ExecPattern::from_string(execution_str),
+            exec_mode,
+        ));
         self.add_verb(
             Some(invocation_str),
             execution,
             VerbDescription::from_code(execution_str.to_string()),
-        ).unwrap()
+        )
+        .unwrap()
     }
 
     pub fn add_verb(
@@ -419,12 +405,8 @@ impl VerbStore {
         description: VerbDescription,
     ) -> Result<&mut Verb, ConfError> {
         let id = self.verbs.len();
-        self.verbs.push(Verb::new(
-            id,
-            invocation_str,
-            execution,
-            description,
-        )?);
+        self.verbs
+            .push(Verb::new(id, invocation_str, execution, description)?);
         Ok(&mut self.verbs[id])
     }
 
@@ -435,7 +417,8 @@ impl VerbStore {
     ) -> Result<(), ConfError> {
         if vc.leave_broot == Some(false) && vc.from_shell == Some(true) {
             return Err(ConfError::InvalidVerbConf {
-                details: "You can't simultaneously have leave_broot=false and from_shell=true".to_string(),
+                details: "You can't simultaneously have leave_broot=false and from_shell=true"
+                    .to_string(),
             });
         }
 
@@ -449,7 +432,7 @@ impl VerbStore {
             let key = crokey::parse(key)?;
             if keys::is_reserved(key) {
                 return Err(ConfError::ReservedKey {
-                    key: keys::KEY_FORMAT.to_string(key)
+                    key: keys::KEY_FORMAT.to_string(key),
                 });
             }
             checked_keys.push(key);
@@ -483,7 +466,9 @@ impl VerbStore {
             // an external
             (Some(ep), None, None, None) => {
                 if let Some(internal_pattern) = ep.as_internal_pattern() {
-                    if let Some(previous_verb) = self.verbs.iter().find(|&v| v.has_name(internal_pattern)) {
+                    if let Some(previous_verb) =
+                        self.verbs.iter().find(|&v| v.has_name(internal_pattern))
+                    {
                         previous_verb.execution.clone()
                     } else {
                         VerbExecution::Internal(InternalExecution::try_from(internal_pattern)?)
@@ -529,11 +514,7 @@ impl VerbStore {
             .clone()
             .map(VerbDescription::from_text)
             .unwrap_or_else(|| VerbDescription::from_code(execution.to_string()));
-        let verb = self.add_verb(
-            invocation.as_deref(),
-            execution,
-            description,
-        )?;
+        let verb = self.add_verb(invocation.as_deref(), execution, description)?;
         for extension in &vc.extensions {
             verb.file_extensions.push(extension.clone());
         }
@@ -592,7 +573,7 @@ impl VerbStore {
 
     /// Return either the only match, or None if there's not
     /// exactly one match
-    pub fn search_sel_info_unique <'v>(
+    pub fn search_sel_info_unique<'v>(
         &'v self,
         prefix: &str,
         sel_info: SelInfo<'_>,
@@ -663,7 +644,9 @@ impl VerbStore {
         stype: SelectionType,
     ) -> Option<String> {
         for verb in &self.verbs {
-            if verb.get_internal() == Some(internal) && verb.selection_condition.accepts_selection_type(stype) {
+            if verb.get_internal() == Some(internal)
+                && verb.selection_condition.accepts_selection_type(stype)
+            {
                 return verb.keys.first().map(|&k| KEY_FORMAT.to_string(k));
             }
         }
@@ -686,10 +669,12 @@ impl VerbStore {
         &self.verbs
     }
 
-    pub fn verb(&self, id: VerbId) -> &Verb {
+    pub fn verb(
+        &self,
+        id: VerbId,
+    ) -> &Verb {
         &self.verbs[id]
     }
-
 }
 
 #[test]
